@@ -27,6 +27,7 @@ serial audio feeds.
 """
 from ..lib.sv_data import Rss as rssFeed #: Rss data parsers
 from ..lib.sv_wrap import wrapText #: Line wrapper
+from ..conf import CACHEDIR
 
 class Format():
     """
@@ -71,7 +72,7 @@ class Format():
             #{ Get rss feed based on its title
             #
             rss = rssFeed(cache.Cache(item['xmlUrl'], rx.toRss(item['title']),
-                workstore=workstore).data())
+                workstore=CACHEDIR).data())
             fileobj.write(
                 self.item(item, rss, rx).encode("ascii", "xmlcharrefreplace")
                 )
@@ -99,7 +100,7 @@ class Format():
         #
         page = ["=" * 80,
             "\n".join(
-                wrapText("FEED TITLE: %s" % PRETITLE.sub("", item['title']))
+                wrapText("FEED TITLE: %s" % rx.PRETITLE.sub("", item['title']))
                 ),
             "\n".join(
                 wrapText("FEED PAGE: %s " % item['htmlUrl'])
@@ -110,7 +111,7 @@ class Format():
         #
         for episode in feed['eps']:
             audiofile = "%s (%.2f MB)" % (episode['title'],
-                toMB(episode['enclosure']['length']))
+                rx.toMB(episode['enclosure']['length']))
             subpage = [
                 "\n".join(
                     wrapText("EPISODE AUDIOFILE: %s" % audiofile, 4)
