@@ -37,7 +37,7 @@ handles a displaying element of the interface concerning feeds.
 @requires: wx.lib.pubsub
 @requires: L{soovee.lib.sv_data}
 @requires: L{soovee.gui.main}
-@requires: L{soovee.lib.sv_conf}
+@requires: L{soovee.conf}
 """
 
 import wx, wx.html, wx.lib.pubsub as msg, wx.lib.statbmp as Cover
@@ -241,7 +241,7 @@ class ViewHtml(wx.html.HtmlWindow):
                 'encloseurl': composer.encloseUrls, 
                 'feedtitle': composer.feedTitle
             }   )
-            self.SetPage("".join(outHtml))
+            self.SetPage(outHtml)
 
         del composer
 
